@@ -1,6 +1,5 @@
 #!/usr/bin/env python3
 
-import functools
 import json
 import os
 import re
@@ -164,12 +163,20 @@ class Shim:
     @contextmanager
     def chrome_manager(self):
         opts = ChromeOptions()
-        opts.add_argument("--load-extension=" + self.extension_path)
+
+        # support tests in Chrome with MV2 PB while this flag remains available
+        opts.add_argument("--enable-features=AllowLegacyMV2Extensions")
+
         opts.binary_location = self.browser_path
+        opts.enable_bidi = True
+        opts.enable_webextensions = True
 
         # work around https://issues.chromium.org/issues/409441960
         opts.add_experimental_option('enableExtensionTargets', True)
 
+        # https://github.com/GoogleChromeLabs/chromium-bidi/issues/3281
+        opts.set_capability("unhandledPromptBehavior", "ignore");
+
         # TODO not yet in Firefox (w/o hacks anyway):
         # https://github.com/mozilla/geckodriver/issues/284#issuecomment-456073771
         opts.set_capability("goog:loggingPrefs", {'browser': 'ALL'})
@@ -177,6 +184,7 @@ class Shim:
         for i in range(5):
             try:
                 driver = webdriver.Chrome(options=opts)
+                driver.webextension.install(self.extension_path)
             except WebDriverException as ex:
                 if i == 0: print("")
                 print(f"ChromeDriver initialization failed: {ex}")
@@ -191,27 +199,24 @@ class Shim:
     @contextmanager
     def edge_manager(self):
         opts = EdgeOptions()
-        opts.add_argument("--load-extension=" + self.extension_path)
+
         opts.binary_location = self.browser_path
+        opts.enable_bidi = True
+        opts.enable_webextensions = True
 
         # work around https://issues.chromium.org/issues/409441960
         opts.add_experimental_option('enableExtensionTargets', True)
 
-        num_tries = 15
-        for i in range(num_tries):
+        # https://github.com/GoogleChromeLabs/chromium-bidi/issues/3281
+        opts.set_capability("unhandledPromptBehavior", "ignore");
+
+        for i in range(5):
             try:
                 driver = webdriver.Edge(options=opts)
-
-                # test for sporadic failure to visit options with EdgeDriver
-                options_url = self.base_url + "skin/options.html"
-                driver.get(options_url)
-                if driver.current_url != options_url:
-                    raise WebDriverException("Failed to open options page")
-
+                driver.webextension.install(self.extension_path)
             except WebDriverException as ex:
                 if i == 0: print("")
-                print(f"EdgeDriver initialization failed ({i+1}/{num_tries}): {ex}", end='')
-                time.sleep(1)
+                print(f"EdgeDriver initialization failed ({i+1}/5): {ex}", end='')
             else:
                 break
 
@@ -296,18 +301,6 @@ def retry_until(fun, tester=None, times=3, msg=None):
     return result
 
 
-def convert_exceptions_to_false(fun, silent=False):
-    def converter(fun, silent):
-        try:
-            result = fun()
-        except Exception as e:
-            if not silent:
-                print("\nCaught exception:", str(e))
-            return False
-        return result
-    return functools.partial(converter, fun, silent)
-
-
 class PBSeleniumTest(unittest.TestCase):
     @classmethod
     def setUpClass(cls):
@@ -332,6 +325,10 @@ class PBSeleniumTest(unittest.TestCase):
         self.test_url = self.base_url + "tests/index.html"
 
     def run(self, result=None):
+        # disable Selenium sending your IP to a third-party company
+        # https://www.selenium.dev/documentation/selenium_manager/#data-collection
+        os.environ['SE_AVOID_STATS'] = "true"
+
         with self.manager() as driver:
             self.init(driver)
 
